@@ -112,8 +112,13 @@ function add_audit_ext($action, $resourcetype, $resourceid, $resourcename, $tabl
 		$resourcename = mb_substr($resourcename, 0, 252).'...';
 	}
 
-	// CWebUser is not initianized in CUser->login() method.
-	$userid = ($action == AUDIT_ACTION_LOGIN) ? $resourceid : CWebUser::$data['userid'];
+	/*
+	 * CWebUser is not initialized in CUser->login() method.
+	 * $userid with value NULL throws DBEXECUTE_ERROR later, so no audit record will be created.
+	 */
+	$userid = ($action == AUDIT_ACTION_LOGIN)
+		? $resourceid
+		: (CWebUser::$data ? CWebUser::$data['userid'] : null);
 
 	$ip = !empty($_SERVER['HTTP_X_FORWARDED_FOR']) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR'];
 	$values = [
