@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -525,7 +525,7 @@ class CMacrosResolverHelper {
 	 *
 	 * @return string
 	 */
-	public static function resolveMapLabelMacros($label, $replaceHosts = null) {
+	public static function resolveMapLabelMacros($label, array $replaceHosts = []) {
 		self::init();
 
 		return self::$macrosResolver->resolveMapLabelMacros($label, $replaceHosts);
