@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ function getLocales() {
 		'ka_GE' => ['name' => _('Georgian (ka_GE)'),	'display' => false],
 		'de_DE' => ['name' => _('German (de_DE)'),	'display' => false],
 		'el_GR' => ['name' => _('Greek (el_GR)'),	'display' => false],
-		'he_IL' => ['name' => _('Hebrew (he_IL)'),	'display' => false],
+		'he_IL' => ['name' => _('Hebrew (he_IL)'),	'display' => true],
 		'hu_HU' => ['name' => _('Hungarian (hu_HU)'),	'display' => false],
 		'id_ID' => ['name' => _('Indonesian (id_ID)'),	'display' => false],
 		'it_IT' => ['name' => _('Italian (it_IT)'),	'display' => true],
@@ -70,10 +70,11 @@ function getLocales() {
 		'ja_JP' => ['name' => _('Japanese (ja_JP)'),	'display' => true],
 		'lv_LV' => ['name' => _('Latvian (lv_LV)'),	'display' => false],
 		'lt_LT' => ['name' => _('Lithuanian (lt_LT)'),	'display' => false],
+		'nb_NO' => ['name' => _('Norwegian (nb_NO)'),	'display' => true],
 		'fa_IR' => ['name' => _('Persian (fa_IR)'),	'display' => false],
 		'pl_PL' => ['name' => _('Polish (pl_PL)'),	'display' => true],
 		'pt_BR' => ['name' => _('Portuguese (pt_BR)'),	'display' => true],
-		'pt_PT' => ['name' => _('Portuguese (pt_PT)'),	'display' => false],
+		'pt_PT' => ['name' => _('Portuguese (pt_PT)'),	'display' => true],
 		'ro_RO' => ['name' => _('Romanian (ro_RO)'),	'display' => false],
 		'ru_RU' => ['name' => _('Russian (ru_RU)'),	'display' => true],
 		'sk_SK' => ['name' => _('Slovak (sk_SK)'),	'display' => true],
@@ -86,18 +87,35 @@ function getLocales() {
 }
 
 /**
- * Return an array of locale name variants based on language.
+ * Get support URL for specified language.
  *
- * @param string $language in format 'ru_RU', 'en_EN' and so on
- * @return array a list of possible locale names
+ * @param string $language  ISO639-1 code or null for English support URL.
+ *
+ * @return string
+ */
+function getSupportUrl($language = null) {
+	$urls = [
+		'ja' => 'https://www.zabbix.com/jp/support',
+		'ru' => 'https://www.zabbix.com/ru/support',
+		'zh' => 'https://www.zabbix.com/cn/support'
+	];
+
+	return array_key_exists($language, $urls) ? $urls[$language] : 'https://www.zabbix.com/support';
+}
+
+/**
+ * Returns an array of locale name variants based on language.
+ *
+ * @param string $language Language in format 'ru_RU', 'en_EN' and so on.
+ *
+ * @return array A list of possible locale names.
  */
 function zbx_locale_variants($language) {
 	if (strtolower(substr(PHP_OS, 0, 3)) === 'win') {
 		return zbx_locale_variants_win($language);
 	}
-	else {
-		return zbx_locale_variants_unix($language);
-	}
+
+	return zbx_locale_variants_unix($language);
 }
 
 function zbx_locale_variants_unix($language) {
@@ -137,19 +155,22 @@ function zbx_locale_variants_unix($language) {
 		'.koi8r',
 		'.tcvn'
 	];
+
 	$result = [];
 	foreach ($postfixes as $postfix) {
 		$result[] = $language.$postfix;
 	}
+
 	return $result;
 }
 
 function zbx_locale_variants_win($language) {
-	// windows locales are written like language[_country[.charset]]
-	// for a list of supported languages see:
+	// Windows locales are written like language[_country[.charset]].
+	// For a list of supported languages see:
 	// http://msdn.microsoft.com/en-us/library/39cwe7zf(vs.71).aspx
 	// http://docs.moodle.org/dev/Table_of_locales#Table
-	$winLanguageName = [
+	// This array should contain all array keys from getLocales() function, but in lowercase.
+	$win_language_names = [
 		'en_gb' => ['English_United Kingdom.1252', 'english-uk'],
 		'en_us' => ['English_United States.1252', 'english-usa'],
 		'bg_bg' => ['Bulgarian_Bulgaria.1251'],
@@ -163,7 +184,7 @@ function zbx_locale_variants_win($language) {
 		'ka_ge' => ['Georgian_Georgia.65001', 'georgian'],
 		'de_de' => ['German_Germany.1252', 'german'],
 		'el_gr' => ['Greek_Greece.1253', 'greek'],
-		'he_IL' => ['Hebrew_Israel.1255', 'hebrew'],
+		'he_il' => ['Hebrew_Israel.1255', 'hebrew'],
 		'hu_hu' => ['Hungarian_Hungary.1250', 'hungarian'],
 		'id_id' => ['Indonesian_indonesia.1252', 'indonesian'],
 		'it_it' => ['Italian_Italy.1252', 'italian'],
@@ -171,6 +192,7 @@ function zbx_locale_variants_win($language) {
 		'ja_jp' => ['Japanese_Japan.932', 'japanese'],
 		'lv_lv' => ['Latvian_Latvia.1257', 'latvian'],
 		'lt_lt' => ['Lithuanian_Lithuania.1257', 'lithuanian'],
+		'nb_no' => ['Norwegian_Norway.1252', 'norwegian'],
 		'fa_ir' => ['Farsi_Iran.1256', 'farsi'],
 		'pl_pl' => ['Polish_Poland.1250', 'polish'],
 		'pt_br' => ['Portuguese_Brazil.1252', 'portuguese-brazil'],
@@ -184,5 +206,6 @@ function zbx_locale_variants_win($language) {
 		'uk_ua' => ['Ukrainian_Ukraine.1251', 'ukrainian'],
 		'vi_vn' => ['Vietnamese_Viet Nam.1258', 'vietnamese']
 	];
-	return $winLanguageName[strtolower($language)];
+
+	return $win_language_names[strtolower($language)];
 }
