@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -55,7 +55,10 @@ if ($data['limited'] || $discovered_item) {
 
 if ($discovered_item) {
 	$form_list->addRow(_('Discovered by'), new CLink($data['item']['discoveryRule']['name'],
-		'disc_prototypes.php?parent_discoveryid='.$data['item']['discoveryRule']['itemid']
+		(new CUrl('disc_prototypes.php'))
+			->setArgument('form', 'update')
+			->setArgument('parent_discoveryid', $data['item']['discoveryRule']['itemid'])
+			->setArgument('itemid', $data['item']['itemDiscovery']['parent_itemid'])
 	));
 }
 
@@ -157,11 +160,11 @@ $form_list
 					(new CCol((new CDiv)->addClass(ZBX_STYLE_DRAG_ICON)))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 					(new CTextBox('query_fields[name][#{index}]', '#{name}', $readonly))
 						->setAttribute('placeholder', _('name'))
-						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
 					'&rArr;',
 					(new CTextBox('query_fields[value][#{index}]', '#{value}', $readonly))
 						->setAttribute('placeholder', _('value'))
-						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
 					(new CButton(null, _('Remove')))
 						->addClass(ZBX_STYLE_BTN_LINK)
 						->setEnabled(!$readonly)
@@ -189,7 +192,7 @@ $form_list
 		],
 		'request_method_row'
 	)
-	// Append ITEM_TYPE_HTTPAGENT Timeout field to fomr list.
+	// Append ITEM_TYPE_HTTPAGENT Timeout field to form list.
 	->addRow(
 		new CLabel(_('Timeout'), 'timeout'),
 		(new CTextBox('timeout', $data['timeout'], $readonly))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
@@ -249,11 +252,11 @@ $form_list
 					(new CCol((new CDiv)->addClass(ZBX_STYLE_DRAG_ICON)))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 					(new CTextBox('headers[name][#{index}]', '#{name}', $readonly))
 						->setAttribute('placeholder', _('name'))
-						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
 					'&rArr;',
-					(new CTextBox('headers[value][#{index}]', '#{value}', $readonly, 1000))
+					(new CTextBox('headers[value][#{index}]', '#{value}', $readonly, 2000))
 						->setAttribute('placeholder', _('value'))
-						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
 					(new CButton(null, _('Remove')))
 						->addClass(ZBX_STYLE_BTN_LINK)
 						->setEnabled(!$readonly)
@@ -317,7 +320,8 @@ $form_list
 			(new CComboBox($readonly ? '' : 'http_authtype', $data['http_authtype'], null, [
 				HTTPTEST_AUTH_NONE => _('None'),
 				HTTPTEST_AUTH_BASIC => _('Basic'),
-				HTTPTEST_AUTH_NTLM => _('NTLM')
+				HTTPTEST_AUTH_NTLM => _('NTLM'),
+				HTTPTEST_AUTH_KERBEROS => _('Kerberos')
 			]))->setEnabled(!$readonly)
 		],
 		'http_authtype_row'
@@ -626,6 +630,7 @@ $form_list
 	->addRow(
 		(new CLabel(_('Executed script'), 'params_es'))->setAsteriskMark(),
 		(new CTextArea('params_es', $data['params']))
+			->addClass(ZBX_STYLE_MONOSPACE_FONT)
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setReadonly($discovered_item),
@@ -634,6 +639,7 @@ $form_list
 	->addRow(
 		(new CLabel(_('SQL query'), 'params_ap'))->setAsteriskMark(),
 		(new CTextArea('params_ap', $data['params']))
+			->addClass(ZBX_STYLE_MONOSPACE_FONT)
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setReadonly($discovered_item),
@@ -642,6 +648,7 @@ $form_list
 	->addRow(
 		(new CLabel(_('Formula'), 'params_f'))->setAsteriskMark(),
 		(new CTextArea('params_f', $data['params'], $discovered_item))
+			->addClass(ZBX_STYLE_MONOSPACE_FONT)
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setReadonly($discovered_item),
@@ -651,13 +658,13 @@ $form_list
 // Append value type to form list.
 if ($readonly) {
 	$form->addVar('value_type', $data['value_type']);
-	$form_list->addRow((new CLabel(_('Type of information'), 'value_type_name'))->setAsteriskMark(),
+	$form_list->addRow(new CLabel(_('Type of information'), 'value_type_name'),
 		(new CTextBox('value_type_name', itemValueTypeString($data['value_type']), true))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 	);
 }
 else {
-	$form_list->addRow((new CLabel(_('Type of information'), 'value_type')),
+	$form_list->addRow(new CLabel(_('Type of information'), 'value_type'),
 		(new CComboBox('value_type', $data['value_type'], null, [
 			ITEM_VALUE_TYPE_UINT64 => _('Numeric (unsigned)'),
 			ITEM_VALUE_TYPE_FLOAT => _('Numeric (float)'),
@@ -745,55 +752,72 @@ $form_list->addRow(_('Custom intervals'),
 );
 
 // Append history storage to form list.
-$keepHistory = [];
-$keepHistory[] = (new CTextBox('history', $data['history'], $discovered_item))
-	->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-	->setAriaRequired();
-
+$keep_history_hint = null;
 if ($data['config']['hk_history_global']
 		&& ($host['status'] == HOST_STATUS_MONITORED || $host['status'] == HOST_STATUS_NOT_MONITORED)) {
-	$keepHistory[] = ' '._x('Overridden by', 'item_form').' ';
+	$link = (CWebUser::getType() == USER_TYPE_SUPER_ADMIN)
+		? (new CLink(_x('global housekeeping settings', 'item_form'), 'adm.housekeeper.php'))
+				->setAttribute('target', '_blank')
+		: _x('global housekeeping settings', 'item_form');
 
-	if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
-		$link = (new CLink(_x('global housekeeping settings', 'item_form'), 'adm.housekeeper.php'))
-			->setAttribute('target', '_blank');
-		$keepHistory[] = $link;
-	}
-	else {
-		$keepHistory[] = _x('global housekeeping settings', 'item_form');
-	}
-
-	$keepHistory[] = ' ('.$data['config']['hk_history'].')';
+	$keep_history_hint = (new CDiv(makeInformationIcon([
+		' '._x('Overridden by', 'item_form').' ',
+		$link,
+		' ('.$data['config']['hk_history'].')'
+	])))
+		->addStyle('margin: 5px 0 0 5px;')
+		->setId('history_mode_hint');
 }
 
 $form_list->addRow((new CLabel(_('History storage period'), 'history'))->setAsteriskMark(),
-	$keepHistory
+	(new CDiv([
+		(new CRadioButtonList('history_mode', (int) $data['history_mode']))
+			->addValue(_('Do not keep history'), ITEM_STORAGE_OFF)
+			->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
+			->setReadonly($discovered_item)
+			->setModern(true),
+		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		(new CTextBox('history', $data['history'], $discovered_item))
+			->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+			->setAriaRequired(),
+		$keep_history_hint
+	]))->addClass('wrap-multiple-controls')
 );
 
 // Append trend storage to form list.
-$keepTrend = [];
-$keepTrend[] = (new CTextBox('trends', $data['trends'], $discovered_item))
-	->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-	->setAriaRequired();
-
+$keep_trend_hint = null;
 if ($data['config']['hk_trends_global']
 		&& ($host['status'] == HOST_STATUS_MONITORED || $host['status'] == HOST_STATUS_NOT_MONITORED)) {
-	$keepTrend[] = ' '._x('Overridden by', 'item_form').' ';
+	$link = (CWebUser::getType() == USER_TYPE_SUPER_ADMIN)
+		? (new CLink(_x('global housekeeping settings', 'item_form'), 'adm.housekeeper.php'))
+				->setAttribute('target', '_blank')
+		: _x('global housekeeping settings', 'item_form');
 
-	if (CWebUser::getType() == USER_TYPE_SUPER_ADMIN) {
-		$link = (new CLink(_x('global housekeeping settings', 'item_form'), 'adm.housekeeper.php'))
-			->setAttribute('target', '_blank');
-		$keepTrend[] = $link;
-	}
-	else {
-		$keepTrend[] = _x('global housekeeping settings', 'item_form');
-	}
-
-	$keepTrend[] = ' ('.$data['config']['hk_trends'].')';
+	$keep_trend_hint = (new CDiv(makeInformationIcon([
+		' '._x('Overridden by', 'item_form').' ',
+		$link,
+		' ('.$data['config']['hk_trends'].')'
+	])))
+		->addStyle('margin: 5px 0 0 5px;')
+		->setId('trends_mode_hint');
 }
 
 $form_list
-	->addRow((new CLabel(_('Trend storage period'), 'trends'))->setAsteriskMark(), $keepTrend, 'row_trends')
+	->addRow((new CLabel(_('Trend storage period'), 'trends'))->setAsteriskMark(),
+		(new CDiv([
+			(new CRadioButtonList('trends_mode', (int) $data['trends_mode']))
+				->addValue(_('Do not keep trends'), ITEM_STORAGE_OFF)
+				->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
+				->setReadonly($discovered_item)
+				->setModern(true),
+			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+			(new CTextBox('trends', $data['trends'], $discovered_item))
+				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+				->setAriaRequired(),
+			$keep_trend_hint
+		]))->addClass('wrap-multiple-controls'),
+		'row_trends'
+	)
 	->addRow(_('Log time format'),
 		(new CTextBox('logtimefmt', $data['logtimefmt'], $readonly, 64))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
 		'row_logtimefmt'
@@ -904,6 +928,7 @@ $form_list
 	->addRow(_('Description'),
 		(new CTextArea('description', $data['description']))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->setMaxlength(DB::getFieldLength('items', 'description'))
 			->setReadonly($discovered_item)
 	)
 	// Append status to form list.
