@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,18 +19,16 @@
 **/
 
 $pageHeader = (new CPageHeader(_('Warning').' ['._s('refreshed every %1$s sec.', 30).']'))
-	->addCssFile('styles/'.CHtml::encode($data['theme']).'.css')
+	->addCssFile('assets/styles/'.CHtml::encode($data['theme']).'.css')
 	->display();
 
 $buttons = array_key_exists('buttons', $data)
 	? $data['buttons']
 	: [(new CButton(null, _('Retry')))->onClick('document.location.reload();')];
 
-echo '<body>';
+echo '<body lang="'.CWebUser::getLang().'">';
 
-(new CDiv(new CWarning($data['header'], $data['messages'], $buttons)))
-	->addClass(ZBX_STYLE_ARTICLE)
-	->show();
+(new CTag('main', true, new CWarning($data['header'], $data['messages'], $buttons)))->show();
 
 echo get_js("setTimeout('document.location.reload();', 30000);");
 echo '</body>';
