@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,8 +50,6 @@ function SVGCanvas(options, shadowBuffer) {
 	var svg_options = options.useViewBox
 		? {
 			'viewBox': '0 0 ' + options.width + ' ' + options.height,
-			'width': '100%',
-			'height': '100%',
 			'style': 'max-width: ' + options.width + 'px; max-height: ' + options.height + 'px;',
 			'preserveAspectRatio': 'xMinYMin meet'
 		}
@@ -641,7 +639,7 @@ ImageCache.prototype.handleCallback = function () {
 };
 
 /**
- * Callback for sucessful image load.
+ * Callback for successful image load.
  *
  * @param {string}     id       Image id.
  * @param {object}     image    Loaded image.
