@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -42,7 +42,6 @@ $knownResourceTypes = [
 	SCREEN_RESOURCE_TRIGGER_INFO,
 	SCREEN_RESOURCE_SERVER_INFO,
 	SCREEN_RESOURCE_CLOCK,
-	SCREEN_RESOURCE_SCREEN,
 	SCREEN_RESOURCE_TRIGGER_OVERVIEW,
 	SCREEN_RESOURCE_DATA_OVERVIEW,
 	SCREEN_RESOURCE_URL,
@@ -270,7 +269,7 @@ $data = [
 	'screenid' => getRequest('screenid', 0)
 ];
 
-// getting updated screen, so we wont have to refresh the page to see changes
+// Getting updated screen, so we won't have to refresh the page to see changes.
 $data['screen'] = API::Screen()->get($options);
 if (empty($data['screen'])) {
 	$data['screen'] = API::TemplateScreen()->get($options);
